sech_vec

Function sech_vec 

pub fn sech_vec(x: &[f64]) -> Vec<f64>
sech_vec(x)

Hyperbolic Function

The sech_vec function calculates the hyperbolic secant value of each angle represented as a radian in the input iterator, constructing a new vector from these results.

Examples

use mathlab::math::sech_vec;
assert_eq!(sech_vec(&[0.0, 0.523598775598299, 3.141592653589793]), [1.0, 0.877009640454779, 0.086266738334054]);

End Fun Doc